<?php
// Remove parent theme styles
add_action('wp_enqueue_scripts', 'change_in_js_css', 20);
function change_in_js_css() {
    // Dequeue parent style if needed (adjust handle)
    wp_dequeue_style('twentytwentyfive-style');
    wp_deregister_style('twentytwentyfive-style');

    // Enqueue child style
    // wp_enqueue_style('twentytwentyfive-style', get_stylesheet_directory_uri() . '/style.css');
}

// menu
function child_theme_register_menus() {
    register_nav_menu('main-menu', 'Main Menu');
    register_nav_menu('footer-menu', 'Footer Menu');
}
add_action('after_setup_theme', 'child_theme_register_menus');
// logo
function child_theme_setup() {
    add_theme_support('custom-logo', array(
        'height'      => 100,
        'width'       => 300,
        'flex-height' => true,
        'flex-width'  => true,
    ));
}
add_action('after_setup_theme', 'child_theme_setup'); 
// Fsf
add_action('customize_register', '__return_true');
// AJAX login handler
add_action('wp_ajax_nopriv_custom_login', 'custom_login_ajax');
function custom_login_ajax() {
    $creds = [
        'user_login'    => sanitize_text_field($_POST['username']),
        'user_password' => $_POST['password'],
        'remember'      => true
    ];

    $user = wp_signon($creds, false);

    if (is_wp_error($user)) {
        wp_send_json_error(['message' => 'Invalid username or password.']);
    } else {
        wp_send_json_success(['message' => 'Login successful.', 'redirect' => home_url()]);
    }
}

// AJAX register handler
add_action('wp_ajax_nopriv_custom_register', 'custom_register_ajax');
function custom_register_ajax() {
    $username = sanitize_user($_POST['username']);
    $email    = sanitize_email($_POST['email']);
    $password = $_POST['password'];

    if (username_exists($username)) {
        wp_send_json_error(['message' => 'Username already exists.']);
    }
    if (email_exists($email)) {
        wp_send_json_error(['message' => 'Email already registered.']);
    }

    $user_id = wp_create_user($username, $password, $email);

    if (is_wp_error($user_id)) {
        wp_send_json_error(['message' => 'Registration failed.']);
    } 
    
    // Auto login
    wp_set_current_user($user_id);
    wp_set_auth_cookie($user_id);
    do_action('wp_login', $username, get_user_by('id', $user_id));

    // Send confirmation email
    $subject = 'Welcome to ' . get_bloginfo('name');
    $message = "Hi $username,\n\nThank you for registering at " . home_url() . ".\nYou are now logged in.\n\nBest regards,\n" . get_bloginfo('name');
    wp_mail($email, $subject, $message);

    // Optional: notify admin
    $admin_email = get_option('admin_email');
    wp_mail($admin_email, 'New User Registration', "A new user has registered:\n\nUsername: $username\nEmail: $email");

    wp_send_json_success(['message' => 'Registration successful. You are now logged in.']);

}
// if login redirect
function redirect_logged_in_user_from_auth_pages() {
    if ( is_user_logged_in() && ( is_page_template('page-login.php') || is_page_template('page-register.php') ) ) {
        wp_redirect( home_url() );
        exit;
    }
}
add_action( 'template_redirect', 'redirect_logged_in_user_from_auth_pages' );
add_action('wp_enqueue_scripts', 'load_my_custom_js', 20);
function load_my_custom_js() {
    wp_enqueue_script('jquery');

    wp_enqueue_script(
        'custom-auth-js',
        get_stylesheet_directory_uri() . '/js/custom.js',
        array('jquery'),
        time(), // forces fresh load every time
        true
    );

    wp_localize_script('custom-auth-js', 'auth_ajax', array(
        'ajaxurl' => admin_url('admin-ajax.php'),
    ));
}
